# History of changes

## Version 0.4.2 (2017-01-21)

### Bugs fixed

**Issues**

* [Issue 65](https://github.com/spyder-ide/qtawesome/issues/65) - Update Appveyor Badge for new username spyder-ide
* [Issue 64](https://github.com/spyder-ide/qtawesome/issues/64) - Integration with system fonts
* [Issue 51](https://github.com/spyder-ide/qtawesome/issues/51) - Include  doc files in PyPi releases

In this release 3 issues were closed

**Pull requests**

* [PR 67](https://github.com/spyder-ide/qtawesome/pull/67) - PR: Add a way to not verify hash of vendorized fonts
* [PR 66](https://github.com/spyder-ide/qtawesome/pull/66) - PR: Update AppVeyor badge because of move to org account
* [PR 63](https://github.com/spyder-ide/qtawesome/pull/63) - Update manifest template

In this release 3 pull requests were merged


----


## Version 0.4.1 (2017-01-02)

### Bugs fixed

**Pull requests**

* [PR 62](https://github.com/spyder-ide/qtawesome/pull/62) - Improve verification that our fonts are not empty and/or missing

In this release 1 pull request was merged


----


## Version 0.4 (2017/01/01)

### New features

* Add a FontError exception to be able to catch an error on Windows 10, which
  prevents reading fonts not installed in the system.

### Bugs fixed

**Issues**

* [Issue 55](https://github.com/spyder-ide/qtawesome/issues/55) - Add appveyor integration
* [Issue 54](https://github.com/spyder-ide/qtawesome/issues/54) - Add travis ci integration for mac
* [Issue 53](https://github.com/spyder-ide/qtawesome/issues/53) - Add circle ci integration for linux

In this release 3 issues were closed

**Pull requests**

* [PR 61](https://github.com/spyder-ide/qtawesome/pull/61) - PR: Fix errors in CI services
* [PR 60](https://github.com/spyder-ide/qtawesome/pull/60) - PR: Add validation to raise exception when fonts are empty or corrupt
* [PR 57](https://github.com/spyder-ide/qtawesome/pull/57) - PR: Simplify appveyor and circle ci config
* [PR 56](https://github.com/spyder-ide/qtawesome/pull/56) - PR: Add ciocheck and circle ci linux integration
* [PR 50](https://github.com/spyder-ide/qtawesome/pull/50) - PR: Conda installation instructions
* [PR 49](https://github.com/spyder-ide/qtawesome/pull/49) - PR: Remove conda recipe
* [PR 48](https://github.com/spyder-ide/qtawesome/pull/48) - PR: Improve documentation

In this release 7 pull requests were merged
